==> chaosmesh-model-6.3.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/GCPChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GCPChaosFluentImpl<A extends GCPChaosFluent<A>> extends BaseFluent<A> implements GCPChaosFluent<A>{
  public GCPChaosFluentImpl() {
  }
  public GCPChaosFluentImpl(GCPChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GCPChaosSpecBuilder spec;
  private GCPChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GCPChaosFluent.MetadataNested<A> withNewMetadata() {
    return new GCPChaosFluentImpl.MetadataNestedImpl();
  }
  public GCPChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GCPChaosFluentImpl.MetadataNestedImpl(item);
  }
  public GCPChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GCPChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GCPChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GCPChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GCPChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GCPChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GCPChaosFluent.SpecNested<A> withNewSpec() {
    return new GCPChaosFluentImpl.SpecNestedImpl();
  }
  public GCPChaosFluent.SpecNested<A> withNewSpecLike(GCPChaosSpec item) {
    return new GCPChaosFluentImpl.SpecNestedImpl(item);
  }
  public GCPChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GCPChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GCPChaosSpecBuilder().build());
  }
  public GCPChaosFluent.SpecNested<A> editOrNewSpecLike(GCPChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GCPChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GCPChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GCPChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GCPChaosFluent.StatusNested<A> withNewStatus() {
    return new GCPChaosFluentImpl.StatusNestedImpl();
  }
  public GCPChaosFluent.StatusNested<A> withNewStatusLike(GCPChaosStatus item) {
    return new GCPChaosFluentImpl.StatusNestedImpl(item);
  }
  public GCPChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GCPChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GCPChaosStatusBuilder().build());
  }
  public GCPChaosFluent.StatusNested<A> editOrNewStatusLike(GCPChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GCPChaosFluentImpl that = (GCPChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GCPChaosFluent.MetadataNested<N>> implements GCPChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GCPChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GCPChaosSpecFluentImpl<GCPChaosFluent.SpecNested<N>> implements GCPChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GCPChaosSpec item) {
      this.builder = new GCPChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GCPChaosSpecBuilder(this);
    }
    GCPChaosSpecBuilder builder;
    public N and() {
      return (N) GCPChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GCPChaosStatusFluentImpl<GCPChaosFluent.StatusNested<N>> implements GCPChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GCPChaosStatus item) {
      this.builder = new GCPChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GCPChaosStatusBuilder(this);
    }
    GCPChaosStatusBuilder builder;
    public N and() {
      return (N) GCPChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/GCPChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GCPChaosFluentImpl<A extends GCPChaosFluent<A>> extends BaseFluent<A> implements GCPChaosFluent<A>{
  public GCPChaosFluentImpl() {
  }
  public GCPChaosFluentImpl(GCPChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GCPChaosSpecBuilder spec;
  private GCPChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GCPChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new GCPChaosFluentImpl.MetadataNestedImpl();
  }
  public GCPChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GCPChaosFluentImpl.MetadataNestedImpl(item);
  }
  public GCPChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GCPChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GCPChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GCPChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GCPChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GCPChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GCPChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new GCPChaosFluentImpl.SpecNestedImpl();
  }
  public GCPChaosFluentImpl.SpecNested<A> withNewSpecLike(GCPChaosSpec item) {
    return new GCPChaosFluentImpl.SpecNestedImpl(item);
  }
  public GCPChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GCPChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GCPChaosSpecBuilder().build());
  }
  public GCPChaosFluentImpl.SpecNested<A> editOrNewSpecLike(GCPChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GCPChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GCPChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GCPChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GCPChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new GCPChaosFluentImpl.StatusNestedImpl();
  }
  public GCPChaosFluentImpl.StatusNested<A> withNewStatusLike(GCPChaosStatus item) {
    return new GCPChaosFluentImpl.StatusNestedImpl(item);
  }
  public GCPChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GCPChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GCPChaosStatusBuilder().build());
  }
  public GCPChaosFluentImpl.StatusNested<A> editOrNewStatusLike(GCPChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GCPChaosFluentImpl that = (GCPChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GCPChaosFluentImpl.MetadataNested<N>> implements GCPChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GCPChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GCPChaosSpecFluentImpl<GCPChaosFluentImpl.SpecNested<N>> implements GCPChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GCPChaosSpec item) {
      this.builder = new GCPChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GCPChaosSpecBuilder(this);
    }
    GCPChaosSpecBuilder builder;
    public N and() {
      return (N) GCPChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GCPChaosStatusFluentImpl<GCPChaosFluentImpl.StatusNested<N>> implements GCPChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GCPChaosStatus item) {
      this.builder = new GCPChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GCPChaosStatusBuilder(this);
    }
    GCPChaosStatusBuilder builder;
    public N and() {
      return (N) GCPChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
